; *********************************************
; Constants
; *********************************************		
GM04		equ 	$F8 			; colour graphics mode 4 (PMODE 0)

PIA0_PDRA	equ 	$ff00
PIA1_PDRB	equ 	$ff22 			; peripheral interface adapter 1 data register B	
SCREEN1		equ 	$0200 			
SCREEN2		equ 	$1A00

; *********************************************
; Init
; *********************************************		
		SETDP $3200
		ORG   $3200

START	; setup VDG & SAM	
		lda 	PIA1_PDRB
		anda 	#$07 			; preserve bits 0-2
		ora 	#GM04 			; overwrite bits 8-3
		sta 	PIA1_PDRB
		JSR		CHGPGE0
		;  000 111
		STA   $FFC0   ; [SAM VDG Reg V0] = A 
		STA   $FFC3   ; [SAM VDG Reg V1] = A 
		STA   $FFC5   ; [SAM VDG Reg V2] = A 
		;  110 -> 6144 (0x1800) bytes per page
		; Clear 2 screen pages
		LDA		#$00
		STA		SCRPGE
		STA		ROWOFF
		LDX		#SCREEN1
		BSR 	PCLS
		LDX		#SCREEN2
		BSR 	PCLS
		
; *********************************************
; MAIN LOOP
; *********************************************	

MAINLO  
		LDX		#SCREEN1
		; Set the new screen page
		LDA		SCRPGE
		BNE		SETPAG2
		LEAX	6144,X
		LDA		#1
		JMP 	SETPAG
SETPAG2	LDA		#0
SETPAG	STA		SCRPGE
		; Clean screen page
		BSR 	PCLS
		; Draw tiles
		LDA		ROWOFF
LOOPROW	BEQ		FOL
		LEAX	32,X
		DECA
		JMP		LOOPROW
FOL		JSR 	DRWTTL
		; Show the new screen page
		JSR		CHGPGE
		; Move tiles down
		LDA		ROWOFF
		INCA
		CMPA	#177
		BNE		CONT
		LDA		#0
CONT	STA		ROWOFF
		JMP 	MAINLO
		
; *********************************************
; PCLS: Clear screen
; *********************************************	

PCLS   	PSHS	X
		LDY   	#TEMPTY
		LDA		#192
		LDU   	,Y
PCLSLOP STU     ,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		STU   	,X++
		DECA
		BNE		PCLSLOP
		PULS	X,PC

; *********************************************
; DRWTTL
; *********************************************	

DRWTTL  LDA	  #16
		LDY   #TDATA
DRWLO	LDU   ,Y++
		STU   32*0,X
		LDU   ,Y++
		STU   32*1,X
		LDU   ,Y++
		STU   32*2,X
		LDU   ,Y++
		STU   32*3,X
		LDU   ,Y++
		STU   32*4,X
		LDU   ,Y++
		STU   32*5,X
		LDU   ,Y++
		STU   32*6,X
		LDU   ,Y++
		STU   32*7,X
		LDU   ,Y++
		STU   32*8,X
		LDU   ,Y++
		STU   32*9,X
		LDU   ,Y++
		STU   32*10,X
		LDU   ,Y++
		STU   32*11,X
		LDU   ,Y++
		STU   32*12,X
		LDU   ,Y++
		STU   32*13,X
		LDU   ,Y++
		STU   32*14,X
		LDU   ,Y++
		STU   32*15,X
		LEAX  2,X
		LEAY  -32,Y
		DECA
		BNE   DRWLO
		RTS

; *********************************************
; CHGPGE: change graphics page 0/1
; *********************************************	

CHGPGE  LDA		SCRPGE
		BNE		CHGPGE1
CHGPGE0	SYNC
		STA		$FFC7   ; [SAM Display Offset bit F0] = 1 
		STA		$FFC8   ; [SAM Display Offset bit F1] = 0 
		STA		$FFCA   ; [SAM Display Offset bit F2] = 0 
		STA		$FFCC   ; [SAM Display Offset bit F3] = 0 
		RTS
CHGPGE1	SYNC
		STA		$FFC7   ; [SAM Display Offset bit F0] = 1 
		STA		$FFC8   ; [SAM Display Offset bit F1] = 0 
		STA		$FFCB   ; [SAM Display Offset bit F2] = 1 
		STA		$FFCD   ; [SAM Display Offset bit F3] = 1
		RTS

; **
; Variables
; **
TDATA  FDB   	$FFFF,$C003,$A005,$9009,$8811,$8421,$8241,$8181,$8181,$8241,$8421,$8811,$9009,$A005,$C003,$FFFF
TEMPTY FDB		$0000
SCRPGE RMB		1
ROWOFF RMB		1
      
		END START